Name:           schedtop
Version:        5.02
Release:        1%{?dist}.4
Summary:        Full-screen curses monitor for PBS and SLURM. Includes Perl bindings for PBS.
Group:          Applications/System
License:        GPL+ or Artistic
URL:            https://svn.princeton.edu/schedtop/
Source0:        https://svn.princeton.edu/schedtop/%{name}-%{version}.tar.gz
Patch1:		fixpermission.patch
Patch2:		addstates.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires:	perl(ExtUtils::MakeMaker) perl-devel
BuildRequires:  perl-generators
BuildRequires:  perl-interpreter
BuildArch:	noarch

# Build with neither pbs or slurm by default.
# Use --with pbs or --with slurm to build pbstop or slurmtop respectively.
%bcond_with pbs
%bcond_without slurm

Requires:  perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description
schedtop is a very convenient way to monitor your PBS or SLURM cluster in a 
terminal window.  It is a full-screen curses monitoring system that provides 
a single screen snapshot of the layout of all jobs on compute nodes, as well 
as a job list that gets automatically refreshed. It is highly customizable 
and supports array job compression.  Build using '--with pbs' to build pbstop 
or '--with slurm' to build slurmtop (but not both).
When building pbstop, includes Perl bindings for the PBS client library.

%if %{with pbs} && %{with slurm}
%{echo:schedtop being built with both '--with pbs' and '--with slurm'. No binary package will be built.
}
%else
%if %{without pbs} && %{without slurm}
%{echo:schedtop being built without '--with pbs' or '--with slurm'. No binary package will be built.
}
%endif
%endif

%if %{with pbs} && %{without slurm}
%package -n pbstop
Summary: Full-screen curses monitor for PBS
Group: Applications/System
# torque-client is needed for pbs_iff
Requires: torque-client
# This isn't picked up by autoreq because it is eval'd in a BEGIN block
# Requires: perl(PBS)

%description -n pbstop
pbstop is a very convenient way to monitor your PBS cluster in a terminal window.
It is a full-screen curses monitoring system that provides a single screen snapshot of
the layout of all jobs on compute nodes, as well as a job list that gets automatically
refreshed. It is highly customizable and supports array job compression.

%package -n perl-PBS
Summary:        Perl bindings for the Portable Batch System client library
Group:          Development/Libraries
Version:        0.35
BuildRequires:  libtorque-devel
%if 0%{?rhel} >= 6 || 0%{?fedora} >= 12 
BuildRequires: perl-devel
%endif

%description -n perl-PBS
This is a Perl binding for the Portable Batch System client library (as from
TORQUE or OpenPBS).  This allows you to stat the server, nodes, or jobs, submit
jobs, alter jobs, etc. Specifically, the ifl, rpp, and rm APIs are implemented here.

%else
%if %{without pbs} && %{with slurm}
%package -n slurmtop
Summary: Full-screen curses monitor for SLURM
Group: Applications/System

# torque-client is needed for pbs_iff
Requires: slurm-perlapi

%description -n slurmtop
slurmtop is a very convenient way to monitor your SLURM cluster in a terminal window.
It is a full-screen curses monitoring system that provides a single screen snapshot of
the layout of all jobs on compute nodes, as well as a job list that gets automatically
refreshed. It is highly customizable and supports array job compression.
%endif
%endif

%if (%{with pbs} && %{without slurm}) || (%{without pbs} && %{with slurm})
%prep
%setup -q -n %{name}
%patch1 -p1
%patch2 -p1
%endif

%if %{with pbs} && %{without slurm}
%build
%{__perl} Makefile.PL pbstop INSTALLDIRS=vendor OPTIMIZE="$RPM_OPT_FLAGS"
make %{?_smp_mflags}
chmod ugo-x demos/*
%else
%build
%if %{without pbs} && %{with slurm}
%{__perl} Makefile.PL slurmtop INSTALLDIRS=vendor
make
%endif
%endif

%if (%{with pbs} && %{without slurm}) || (%{without pbs} && %{with slurm})
%install
rm -rf $RPM_BUILD_ROOT
make pure_install PERL_INSTALL_ROOT=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -type f -name '.packlist' -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type f -name '*.bs' -a -size 0 -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type f -name 'schedtop.3*' -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type f -name '.dummy' -exec rm -f {} ';'
find $RPM_BUILD_ROOT -type d -depth -exec rmdir {} 2>/dev/null ';'
chmod -R u+w $RPM_BUILD_ROOT/*
%endif

%if %{with pbs} && %{without slurm}
%check
make test
%endif

%if (%{with pbs} && %{without slurm}) || (%{without pbs} && %{with slurm})
%clean
rm -rf $RPM_BUILD_ROOT
%endif

%if %{with pbs} && %{without slurm}
%files -n pbstop
%defattr(-,root,root,-)
%doc README LICENSE Artistic CHANGELOG
%{perl_vendorarch}/schedtop.pm
%{_bindir}/pbstop
%{_mandir}/man1/pbstop.1*

%files -n perl-PBS
%defattr(-,root,root,-)
%doc README LICENSE Artistic CHANGELOG demos
%{perl_vendorarch}/auto/*
%{perl_vendorarch}/PBS
%{perl_vendorarch}/PBS.pm
%{_mandir}/man3/PBS*.3*

%else
%if %{without pbs} && %{with slurm}
%files -n slurmtop
%defattr(-,root,root,-)
%doc README LICENSE Artistic CHANGELOG
%{perl_vendorlib}/schedtop.pm
%{_bindir}/slurmtop
%{_mandir}/man1/slurmtop.1*
%endif
%endif


%changelog
* Fri Aug 28 2015 Princeton University Research Computing release - <cses@princeton.edu> - 5.02-01
- Remove libtorque-devel and perl-devel build dependencies when doing a "--with slurm" build.
- See CHANGELOG for additional details. pbstop/slurmtop to 5.02, perl-PBS at 0.35

* Wed Aug 19 2015 Princeton University Research Computing release - <cses@princeton.edu> - 5.01-01
- See CHANGELOG for details. pbstop/slurmtop to 5.01, perl-PBS at 0.35

* Mon Aug 03 2015 Princeton University Research Computing release - <cses@princeton.edu> - 5.00-01
- See CHANGELOG for details. pbstop/slurmtop to 5.00, perl-PBS at 0.35

* Tue Oct 21 2014 Princeton University Research Computing release - <cses@princeton.edu> - 0.35-01
- See CHANGELOG for details. pbstop/slurmtop to 4.21, perl-PBS to 0.35

* Mon Aug 04 2014 Princeton University Research Computing release - <cses@princeton.edu> - 0.34-01
- See CHANGELOG for details. pbstop/slurmtop to 4.20, perl-PBS to 0.34

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.33-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jun 17 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.33-14
- Perl mass rebuild

* Fri Jun 10 2011 Marcela Mašláňová <mmaslano@redhat.com> - 0.33-13
- Perl 5.14 mass rebuild

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.33-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.33-11
- 661697 rebuild for fixing problems with vendorach/lib

* Tue Aug 10 2010 Steve Traylen <steve.traylen@cern.ch> - 0.33-10
- Adjust perl-devel BR to build on .el4 and .el5 as well.

* Tue Jun 22 2010 Petr Pisar <ppisar@redhat.com> - 0.33-9
- Rebuild against libtorque-2.4.8

* Wed Jun 02 2010 Tom "spot" Callaway <tcallawa@redhat.com> - 0.33-8
- remove obsolete functions no longer in torque

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.33-7
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.33-6
- rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.33-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.33-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.33-3
Rebuild for new perl

* Thu Feb 14 2008 Garrick Staples <garrick@usc.edu> 0.33-2
- rebuilding for fedora9

* Wed Oct  3 2007 Garrick Staples <garrick@usc.edu> 0.33-1
- bump to 0.33, pbstop to 4.16

* Fri Sep  8 2006 Garrick Staples <garrick@usc.edu> 0.31-3
- previous build is mysteriously missing from devel repo

* Sun Aug 27 2006 Garrick Staples <garrick@usc.edu> 0.31-2
- FC6 mass rebuild

* Wed Apr 19 2006 Garrick Staples <garrick@usc.edu> 0.31-1
- Initial spec file
